@@ -1,6 +1,6 @@
 package App::rank;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 1;
 # ABSTRACT: Rank lines of text files
@@ -17,7 +17,7 @@ App::rank - Rank lines of text files
 
 =head1 VERSION
 
-This document describes version 0.002 of App::rank (from Perl distribution App-rank), released on 2018-04-22.
+This document describes version 0.003 of App::rank (from Perl distribution App-rank), released on 2018-04-22.
 
 =head1 SYNOPSIS
 
@@ -39,6 +39,10 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<List::Rank>, L<Sort::Rank>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
